##  Importing More Projects
Each fact sheet can be synced with only one project. However, you can link multiple projects as child fact sheets, allowing you to import and connect subprojects under the main initiative.
Once a project has been imported as a child fact sheet, it is listed in the Agile Tracking tab of the parent fact sheet. To import more projects, click Import More Projects under the list and proceed with importing additional projects.
![Importing More Projects as Child Fact Sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274ba79a7a441014afc487e071c38987_LowRes.png)
Importing More Projects as Child Fact Sheet
